@@ -1,12 +1,11 @@
 {-# LANGUAGE RankNTypes #-}
-{-# LANGUAGE OverloadedStrings #-}
 {-# OPTIONS -Wall #-}
 
 -- |
 -- Module      : Text.Format
 -- Copyright   : (c) 2013 Chris Done, 2013 Shachaf Ben-Kiki
 -- License     : BSD3
--- Maintainer  : chrisdone@gmail.com
+-- Maintainer  : alex@farfromthere.net
 -- Stability   : experimental
 -- Portability : GHC
 --
@@ -16,7 +15,8 @@
 --
 -- >>> format ("Person's name is " % text % ", age is " % hex) "Dave" 54
 --
--- See "Formatting.Formatters" for a complete list of formatting combinators.
+-- See "Formatting.Formatters" for a list of formatters.
+-- See "Formatting.Combinators" for a list of formatting combinators, for combining and altering formatters.
 
 module Formatting
   (
@@ -31,12 +31,17 @@ module Formatting
   format,
   sformat,
   bprint,
+  bformat,
   fprint,
+  fprintLn,
   hprint,
+  hprintLn,
   formatToString,
   -- * Formatting library
-  module Formatting.Formatters
+  module Formatting.Formatters,
+  module Formatting.Combinators
  ) where
 
 import Formatting.Formatters
+import Formatting.Combinators
 import Formatting.Internal
