@@ -3,11 +3,27 @@
 
 -- | Internal format starters.
 
-module Formatting.Internal where
+module Formatting.Internal
+  ( Format(..)
+  , (%)
+  , (%.)
+  , now
+  , bind
+  , mapf
+  , later
+  , format
+  , sformat
+  , bprint
+  , bformat
+  , fprint
+  , fprintLn
+  , hprint
+  , hprintLn
+  , formatToString
+  ) where
 
 import           Control.Category (Category(..))
 import           Data.Monoid
-import qualified Data.Semigroup
 import           Data.String
 import qualified Data.Text as S (Text)
 import           Data.Text.Lazy (Text)
@@ -26,7 +42,7 @@ import           System.IO
 -- will be formatted.  For example, in
 --
 -- @
--- myFormat :: Formatter r (Text -> Int -> r)
+-- myFormat :: Format r (Text -> Int -> r)
 -- myFormat = \"Person's name is \" % text % \", age is \" % hex
 -- @
 --
@@ -44,22 +60,32 @@ import           System.IO
 newtype Format r a =
   Format {runFormat :: (Builder -> r) -> a}
 
--- | Not particularly useful, but could be.
+-- | This can be used almost like contramap, e.g:
+--
+-- @
+-- formatter :: Format r (b -> r)
+-- formatter = _
+-- 
+-- adapter :: a -> b
+-- adapter = _
+-- 
+-- adapted :: Format r (a -> r)
+-- adapted = fmap (. adapter) formatter
+-- @
 instance Functor (Format r) where
-  fmap f (Format k) = Format (\br -> f (k br))
+  fmap f (Format k) = Format (f . k)
+
+instance Semigroup (Format r (a -> r)) where
+  m <> n =
+    Format (\k a ->
+              runFormat m (\b1 -> runFormat n (\b2 -> k (b1 <> b2)) a) a)
 
 -- | Useful instance for applying two formatters to the same input
 -- argument. For example: @format (year <> "/" % month) now@ will
 -- yield @"2015/01"@.
 instance Monoid (Format r (a -> r)) where
-  mappend m n =
-    Format (\k a ->
-              runFormat m (\b1 -> runFormat n (\b2 -> k (b1 <> b2)) a) a)
   mempty = Format (\k _ -> k mempty)
 
-instance Data.Semigroup.Semigroup (Format r (a -> r)) where
-  (<>) = mappend
-
 -- | Useful instance for writing format string. With this you can
 -- write @"Foo"@ instead of @now "Foo!"@.
 instance (a ~ r) => IsString (Format r a) where
@@ -96,14 +122,14 @@ instance Category Format where
 -- @
 --
 -- @
--- myFormat :: Formatter r (Text -> Int -> r)
+-- myFormat :: Format r (Text -> Int -> r)
 -- myFormat = format1 % format2 % format3
 -- @
 --
 -- Notice how the argument types of @format1@ and @format3@ are
 -- gathered into the type of @myFormat@.
 --
--- (This is actually the composition operator for 'Format''s
+-- (This is actually the composition operator for 'Format's
 -- 'Category' instance, but that is (at present) inconvenient to use
 -- with regular "Prelude". So this function is provided as a
 -- convenience.)
@@ -147,14 +173,28 @@ sformat m = runFormat m (T.toStrict . T.toLazyText)
 bprint :: Format Builder a -> a
 bprint m = runFormat m id
 
+-- | Run the formatter and return a 'Builder' value.
+-- 
+-- This is a newer synonym for 'bprint', following the naming convention set by 'format' and 'sformat'.
+bformat :: Format Builder a -> a
+bformat m = runFormat m id
+
 -- | Run the formatter and print out the text to stdout.
 fprint :: Format (IO ()) a -> a
 fprint m = runFormat m (T.putStr . T.toLazyText)
 
+-- | Run the formatter and print out the text to stdout, followed by a newline.
+fprintLn :: Format (IO ()) a -> a
+fprintLn m = runFormat m (T.putStrLn . T.toLazyText)
+
 -- | Run the formatter and put the output onto the given 'Handle'.
 hprint :: Handle -> Format (IO ()) a -> a
 hprint h m = runFormat m (T.hPutStr h . T.toLazyText)
 
+-- | Run the formatter and put the output and a newline onto the given 'Handle'.
+hprintLn :: Handle -> Format (IO ()) a -> a
+hprintLn h m = runFormat m (T.hPutStrLn h . T.toLazyText)
+
 -- | Run the formatter and return a list of characters.
-formatToString :: Format [Char] a -> a
+formatToString :: Format String a -> a
 formatToString m = runFormat m (TL.unpack . TLB.toLazyText)
